Description Usage Format Source Examples
The EML data give profile measurements from Eagle Mountain Lake containing depth profiles of water quality variables. EML is a reservoir in North Texas, formed by damming the West Fork of the Trinity River. This reservoir is used for recreation, and people live all around it. Data was collected beginning on April 25, 2019 and ending on September 12 2019. It was collected at 21 depths, every 0.5 meters from 0.0 (surface) to 10.0 meters. A vertical profile measurement was taken once every two hours. All times are in UTC.
1 2 |
An object of class "data.frame" with 35532 rows and 7 columns:
Date and two-hour time period measurement was taken
Profile Depth, measured in meters
Water Temperature, measured in degrees Celsius
Dissolved Oxygen, measured in mg/L
Dissolved Oxygen Saturation, measured as the percentage of DO relative to what the concentration would be in equilibrium with the atmosphere, calcualted as actual/expected
pH, measured as standard pH from 0 (basic) to 14 (acidic)
Conductivity in water, measured in μS/cm (micro Siemens per centimeter)
Professor Thad Scott from the Department of Biology at Baylor University provided this data. Tarrant Regional Water District (TRWD) provided funding for the first year of data collection, and Eagle Mountain Lake is owned and operated by TRWD. This lake is used to supply water to municipalities within the Dallas/Fort Worth area. See http://ec2-18-223-67-99.us-east-2.compute.amazonaws.com/test2/testIndex.html
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 | #- check out data
head(eml)
#- histogram of variable of interest
hist(eml$DOsat)
#- profile plots
dosat <- eml$DOsat
depths <- seq(0, 10, length.out = 21)
plot(dosat[1:21], depths,
type = "l", xlab = "DOsat",
xlim = c(-10, 220), ylim = c(10, 0))
for (i in 2:(length(dosat)/21)) {
last <- i*21
first <- last - 20
lines(dosat[first:last], depths)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.